Name:           minion
Version:        1.6.1        
Release:        6%{?dist}
Summary:        Fast, Scalable Constraint Solving

Group:          Development/Libraries          
License:        GPLv2+
URL:            http://minion.sourceforge.net/
Source0:        %{name}-%{version}-linux-without-nauty.tar.gz
#
# clean release source of naughty non free library
#
Source1:        minion-generate-tarball.sh
#
# patch0 : add custom option to add capability to set the fedora flags in another variable
# patch reported to upstream : https://mail.cs.st-andrews.ac.uk/pipermail/mug/2010-August/000061.html
#
Patch0:         %{name}-%{version}-patch0-add-custom-compil-flags-options.patch

BuildRequires:  cmake
BuildRequires:  boost-devel
BuildRequires:  doxygen
BuildRequires:  graphviz
BuildRequires:  zlib-devel
BuildRequires:  bzip2-devel

%package examples
Summary:        Example code for %{name}
Group:          Documentation
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description
MINION is a new constraint solver, which is very fast and scales
well as problem size increases. Empirical results on standard
benchmarks show orders of magnitude performance gains over
state-of-the-art constraint toolkits. These gains increase with
problem size --- MINION delivers scalable constraint solving.

%description examples
The %{name}-examples package contains example code for %{name}.

%prep
%setup -q
%patch0 -p1
#
# set good rights to headers for debuginfo package
#
find . \( -name "*.h" -o -name "*.hpp" \) -exec chmod 0644 {} \;
#
# suppress -s to linking flags (otherwise no debuginfo)
#
sed -i "/set(CMAKE_EXE_LINKER_FLAGS/s/-s//g" CMakeLists.txt
#
# unbzip2 minion compressed file in examples dirs
#
find ./benchmarks ./generators -type f -name *.bz2 -exec bzip2 -d {} \;
#
# supress windows EOL style
#
find ./benchmarks ./generators -type f -exec sed -i 's/\r//' {} \;

%build
mkdir builddir
pushd builddir
%cmake -DCUSTOM_CXX_FLAGS=1 \
       -DCUSTOM_MINION_CFLAGS:STRING="%{optflags}" \
       -DNAUTY=0 ..
#
# disable ?_smp_mflags due to koji restriction
# compilling multiple file in parallel consume too
# memory and cause gcc bugs. 
#
make VERBOSE=1 api-doc
make VERBOSE=1

%install
# set good rights to examples files
find ./benchmarks ./generators -type f -exec chmod 0644 {} \;

# install executable
install -m 0755 -D -p ./builddir/%{name} %{buildroot}%{_bindir}/%{name}

# useless Lisp files not to be installed
# see devel comment : https://mail.cs.st-andrews.ac.uk/pipermail/mug/2010-August/000059.html
find . -type f -name *.lsp -delete

%files
%defattr(-,root,root,-)
%{_bindir}/%{name}
%doc README
%doc LICENSE.txt
%doc docs/Manual.pdf

%files examples
%defattr(-,root,root,-)
%doc benchmarks
%doc generators

%changelog
* Mon Jan 26 2015 Petr Machata <pmachata@redhat.com> - 1.6.1-6
- Rebuild for boost 1.57.0

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri May 23 2014 Petr Machata <pmachata@redhat.com> - 1.6.1-3
- Rebuild for boost 1.55.0

* Tue Nov 05 2013 Alexis Lameire <alexisis-pristontale@hotmail.com> - 1.6.1-2
- Solve too memory consuption in koji

* Mon Oct 28 2013 Alexis Lameire <alexisis-pristontale@hotmail.com> - 1.6.1-1
- Update to 1.6.1 upstream release
- incorrect fsf address reported to upstream

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.14-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sat Jul 27 2013 pmachata@redhat.com - 0.14-5
- Rebuild for boost 1.54.0

* Sun Feb 10 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.14-4
- Rebuild for Boost-1.53.0

* Sat Feb 09 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.14-3
- Rebuild for Boost-1.53.0

* Fri Aug 10 2012 Alexis Lameire <alexisis-pristontale@hotmail.com> - 0.14-2
- Rebuild for new boost_istream

* Fri Jul 27 2012 Alexis Lameire <alexisis-pristontale@hotmail.com> - 0.14-1
- Update to 0.14 upstream release

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10-10
- Rebuilt for c++ ABI breakage

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Fri Dec 23 2011 Peter Robinson <pbrobinson@fedoraproject.org> - 0.10-8
- Rebuild for new boost again

* Tue Oct 11 2011 Peter Robinson <pbrobinson@fedoraproject.org> - 0.10-7
- Rebuild for new boost

* Sun Apr 17 2011 Kalev Lember <kalev@smartlink.ee> - 0.10-6
- Rebuilt for boost 1.46.1 soname bump

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sat Aug 28 2010 alexisis-pristontale@hotmail.com - 0.10-4
- set 644 rights to SOURCE1

* Tue Aug 24 2010 Lameire Alexis <alexisis-pristontale@hotmail.com> - 0.10-3
- repack source without nauty dir for legal reasons

* Wed Aug 18 2010 Lameire Alexis <alexisis-pristontale@hotmail.com> - 0.10-2
- put examples on doc dir
- attach upstream report link to the patch 0
- one file in doc package : supress it
- supress windows EOL style
- unbzip2 minion compressed examples files
- set good rights to examples files

* Mon Aug 16 2010 Lameire Alexis <alexisis-pristontale@hotmail.com> - 0.10-1
- initial release
